Struct ZwpTabletPadStripV2
pub struct ZwpTabletPadStripV2 { /* private fields */ }wayland and Linux only.Expand description
pad strip
A linear interaction area, such as the strips found in Wacom Cintiq models.
Events on a strip are logically grouped by the zwp_tablet_pad_strip_v2.frame event.
See also the Request enum for this interface.
Implementations
impl ZwpTabletPadStripV2
impl ZwpTabletPadStripV2
pub fn source(&self, source: Source)
pub fn source(&self, source: Source)
strip event source
Source information for strip events.
This event does not occur on its own. It is sent before a zwp_tablet_pad_strip_v2.frame event and carries the source information for all events within that frame.
The source specifies how this event was generated. If the source is zwp_tablet_pad_strip_v2.source.finger, a zwp_tablet_pad_strip_v2.stop event will be sent when the user lifts their finger off the device.
This event is optional. If the source is unknown for an interaction, no event is sent.
pub fn position(&self, position: u32)
pub fn position(&self, position: u32)
position changed
Sent whenever the position on a strip changes.
The position is normalized to a range of [0, 65535], the 0-value represents the top-most and/or left-most position of the strip in the pad’s current rotation.
pub fn stop(&self)
pub fn stop(&self)
interaction stopped
Stop notification for strip events.
For some zwp_tablet_pad_strip_v2.source types, a zwp_tablet_pad_strip_v2.stop event is sent to notify a client that the interaction with the strip has terminated. This enables the client to implement kinetic scrolling. See the zwp_tablet_pad_strip_v2.source documentation for information on when this event may be generated.
Any zwp_tablet_pad_strip_v2.position events with the same source after this event should be considered as the start of a new interaction.
pub fn frame(&self, time: u32)
pub fn frame(&self, time: u32)
end of a strip event sequence
Indicates the end of a set of events that represent one logical hardware strip event. A client is expected to accumulate the data in all events within the frame before proceeding.
All zwp_tablet_pad_strip_v2 events before a zwp_tablet_pad_strip_v2.frame event belong logically together. For example, on termination of a finger interaction on a strip the compositor will send a zwp_tablet_pad_strip_v2.source event, a zwp_tablet_pad_strip_v2.stop event and a zwp_tablet_pad_strip_v2.frame event.
A zwp_tablet_pad_strip_v2.frame event is sent for every logical event group, even if the group only contains a single zwp_tablet_pad_strip_v2 event. Specifically, a client may get a sequence: position, frame, position, frame, etc.